CREATE DATABASE overstock
GO

USE [overstock]
GO

/* Creating Table SalesOrder*/

	CREATE TABLE [dbo].[salesorder](
		[SalesOrderID] [int] IDENTITY(1,1) NOT NULL,
		[PurchaseOrderType] [nvarchar](50) NULL,
		[SupplierOrderNumber] [nvarchar](50) NULL,
		[RetailerOrderNumber] [nvarchar](50) NULL,
		[OrderDate] [smalldatetime] NULL,
		[WarehouseName] [nvarchar](50) NULL,
		[RetailerName] [nvarchar](50) NULL,
		[CarrierCode] [nvarchar](50) NULL,
		[ShippingStreet] [nvarchar](50) NULL,
		[ShippingCity] [nvarchar](50) NULL,
		[ShippingState] [nvarchar](50) NULL,
		[ShippingZip] [nvarchar](50) NULL,
		[ShippingCountry] [nvarchar](50) NULL,
		[ShippingPhone] [nvarchar](50) NULL,
		[ShippingName] [nvarchar](50) NULL,
		[CustomerName] [nvarchar](50) NULL,
		[BillingStreet] [nvarchar](50) NULL,
		[BillingCity] [nvarchar](50) NULL,
		[BillingState] [nvarchar](50) NULL,
		[BillingZip] [nvarchar](50) NULL,
		[BillingCountry] [nvarchar](50) NULL,
		[CustomerPhone] [nvarchar](50) NULL,
		[NumberofLineItems] [nvarchar](50) NULL,
	 CONSTRAINT [PK_salesorder] PRIMARY KEY CLUSTERED 
	(
		[SalesOrderID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO


/*Creating Table SalesOrderLineItems*/


	CREATE TABLE [dbo].[salesorderlineitems](
		[LineItemID] [int] IDENTITY(1,1) NOT NULL,
		[SalesOrderID] [int] NULL,
		[LineNumber] [nvarchar](50) NULL,
		[SupplierSKU] [nvarchar](50) NULL,
		[RetailerSKU] [nvarchar](50) NULL,
		[QuantityOrdered] int null,
		[UnitPrice] [decimal](8, 2) NULL,
		[UPCNumber] int null,
		[ISBNNumber] int null,
		[ManufacturerPartNumber] int null,
		[ProductDescription] nvarchar](50) NULL,
	 CONSTRAINT [PK_salesorderlineitems] PRIMARY KEY CLUSTERED 
	(
		[LineItemID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO


/*Creating Table Invoice*/

	CREATE TABLE [dbo].[invoice](
		[InvoiceID] [int] IDENTITY(1,1) NOT NULL,
		[InvoiceDate] [smalldatetime] NULL,
		[InvoiceNumber] [nvarchar](50) NULL,
		[SupplierOrderNumber] [nvarchar](50) NULL,
		[RetailerOrderNumber] [nvarchar](50) NULL,
		[CurrencyName] [nvarchar](50) NULL,
		[SellerInvoiceNumber] [nvarchar](50) NULL,
		[RetailerInvoiceNumber] [nvarchar](50) NULL,
		[RemittingName] [nvarchar](50) NULL,
		[RemittingStreet] [nvarchar](50) NULL,
		[RemittingCity] [nvarchar](50) NULL,
		[RemittingState] [nvarchar](50) NULL,
		[RemittingZip] [nvarchar](50) NULL,
		[RemittingCountry] [nvarchar](50) NULL,
		[CustomerName] [nvarchar](50) NULL,
		[BillingStreet] [nvarchar](50) NULL,
		[BillingCity] [nvarchar](50) NULL,
		[BillingState] [nvarchar](50) NULL,
		[BillingZip] [nvarchar](50) NULL,
		[BillingCountry] [nvarchar](50) NULL,
		[TermsDueDate] [smalldatetime] NULL,
		[TermsNetDays] [nvarchar](50) NULL,
		[DescriptionofTerms] [nvarchar](50) NULL,
		[ShippingDate] [smalldatetime] NULL,
		[Subtotal] [decimal](8, 2) NULL,
		[Total] [decimal](8, 2) NULL,
		[SACInfo] [nvarchar](50) NULL,
		[SACService] [nvarchar](50) NULL,
		[SACAmount] [nvarchar](50) NULL,
		[SACAllowance] [nvarchar](50) NULL,
		[SACDescription] [nvarchar](50) NULL,

	 CONSTRAINT [PK_invoice] PRIMARY KEY CLUSTERED 
	(
		[InvoiceID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO


/*Creating Table InvoiceLineItems */

	CREATE TABLE [dbo].[invoicelineitems](
		[InvoiceLineItemID] [int] IDENTITY(1,1) NOT NULL,
		[LineNumber] [nvarchar](50) NULL,
		[QuantityInvoiced] [nvarchar](50) NULL,
		[UnitPrice] [decimal](8, 2) NULL,
		[ProductId] [nvarchar](50) NULL,
		[ProductDescription] [nvarchar](50) NULL,
		[InvoiceID] [int] NULL,
	 CONSTRAINT [PK_invoicelineitems] PRIMARY KEY CLUSTERED 
	(
		[InvoiceLineItemID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO


/*  Creating Table Items    */

	CREATE TABLE [dbo].[items](
		[ItemID] [int] IDENTITY(1,1) NOT NULL,
		[SupplierRef] [nvarchar](25) NULL,
		[InquiryDate] [smalldatetime] NULL,
		[WarehouseName] [nvarchar](50) NULL,
		[SupplierAccountName] [nvarchar](25) NULL,
		[ProductID] [nvarchar](25) NULL,
		[LineNumber] [int] NULL,
		[QuantityAvailable] [int] NULL,
	 CONSTRAINT [PK_ItemID] PRIMARY KEY CLUSTERED 
	(
		[ItemID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO


/* Creating Table ASNShipment */

	CREATE TABLE [dbo].[asnshipment](
		[ASNShipmentID] [int] IDENTITY(1,1) NOT NULL,
		[PackingSlipNumber] [nvarchar](25) NULL,
		[TransactionSetDate] [smalldatetime] NULL,
		[PackingType] [nvarchar](25) NULL,
		[NumberofUnits] [int] NULL,
		[WeightofShipment] [decimal](8, 2) NULL,
		[ServiceLevelCode] [nvarchar](25) NULL,
		[Warehouse] [nvarchar](25) NULL,
		[RetailerName] [nvarchar](25) NULL,
		[ShippingDate] [smalldatetime] NULL,
		[ShippingName] [nvarchar](30) NULL,
		[ShippingStreet] [nvarchar](30) NULL,
		[ShippingCity] [nvarchar](25) NULL,
		[ShippingState] [nvarchar](25) NULL,
		[ShippingZip] [nvarchar](25) NULL,
		[ShippingCountry] [nvarchar](25) NULL,
		[HLID] [nvarchar](25) NULL,
		[SACAmount] [decimal](8, 2) NULL,
		[TransportationMethod] [varchar](45) NULL,
	 CONSTRAINT [PK_ASNShipmentID] PRIMARY KEY CLUSTERED 
	(
		[ASNShipmentID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO


/* Creating Table ASNOrder */

	CREATE TABLE [dbo].[asnorder](
		[ASNOrderID] [int] IDENTITY(1,1) NOT NULL,
		[HLID] [nvarchar](25) NULL,
		[HLParentID] [nvarchar](25) NULL,
		[SupplierOrderNumber] [nvarchar](25) NULL,
		[RetailerOrderNumber] [nvarchar](25) NULL,
		[OrderDate] [smalldatetime] NULL,
		[ASNShipmentID] [int] NULL,

	 CONSTRAINT [PK_ASNOrderID] PRIMARY KEY CLUSTERED 
	(
		[ASNOrderID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO
	
/* CREATE TABLE ASNPackage  */

	CREATE TABLE [dbo].[asnpackage](
		[ASNPackageID] [int] IDENTITY(1,1) NOT NULL,
		[HLID] [nvarchar](25) NULL,
		[HLParentID] [nvarchar](25) NULL,
		[TrackingNumber] [nvarchar](25) NULL,
		[ASNOrderID] [int] NULL,

	CONSTRAINT [PK_ASNPackageID] PRIMARY KEY CLUSTERED 
	(
		[ASNPackageID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO

 /* CREATE TABLE ASNItem   */

	CREATE TABLE [dbo].[asnitem](
		[ASNItemID] [int] IDENTITY(1,1) NOT NULL,
		[HLID] [nvarchar](25) NULL,
		[HLParentID] [nvarchar](25) NULL,
		[LineItemID] [nvarchar](25) NULL,
		[SupplierSKUNumber] [nvarchar](25) NULL,
		[QuantityShipped] [int] NULL,
		[QuantityOrdered] [int] NULL,
		[ASNPackageID] [int] NULL,

	CONSTRAINT [PK_ASNItemID] PRIMARY KEY CLUSTERED 
	(
		[ASNItemID] ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
	) ON [PRIMARY]

	GO

























